aboutsummaryrefslogtreecommitdiffstats
path: root/src/redshift.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/redshift.c')
-rw-r--r--src/redshift.c39
1 files changed, 26 insertions, 13 deletions
diff --git a/src/redshift.c b/src/redshift.c
index c1fc259..429ae38 100644
--- a/src/redshift.c
+++ b/src/redshift.c
@@ -25,7 +25,6 @@
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
-#include <time.h>
#include <math.h>
#include <locale.h>
#include <errno.h>
@@ -300,6 +299,7 @@ typedef enum {
/* Names of periods of day */
static const char *period_names[] = {
+ /* TRANSLATORS: Name printed when period of day is unknown */
N_("None"),
N_("Daytime"),
N_("Night"),
@@ -1172,12 +1172,25 @@ main(int argc, char *argv[])
provider->free(&location_state);
if (verbose) {
- /* TRANSLATORS: Append degree symbols after %f if possible. */
+ /* TRANSLATORS: Abbreviation for `north' */
+ const char *north = _("N");
+ /* TRANSLATORS: Abbreviation for `south' */
+ const char *south = _("S");
+ /* TRANSLATORS: Abbreviation for `east' */
+ const char *east = _("E");
+ /* TRANSLATORS: Abbreviation for `west' */
+ const char *west = _("W");
+
+ /* TRANSLATORS: Append degree symbols after %f if possible.
+ The string following each number is an abreviation for
+ north, source, east or west (N, S, E, W). */
printf(_("Location: %.2f %s, %.2f %s\n"),
- fabs(lat), lat >= 0.f ? _("N") : _("S"),
- fabs(lon), lon >= 0.f ? _("E") : _("W"));
+ fabs(lat), lat >= 0.f ? north : south,
+ fabs(lon), lon >= 0.f ? east : west);
+
printf(_("Temperatures: %dK at day, %dK at night\n"),
day.temperature, night.temperature);
+
/* TRANSLATORS: Append degree symbols if possible. */
printf(_("Solar elevations: day above %.1f, night below %.1f\n"),
transition_high, transition_low);
@@ -1261,10 +1274,12 @@ main(int argc, char *argv[])
}
if (verbose) {
+ /* TRANSLATORS: The string in parenthesis is either
+ Daytime or Night (translated). */
printf(_("Gamma (%s): %.3f, %.3f, %.3f\n"),
- "Day", day.gamma[0], day.gamma[1], day.gamma[2]);
+ _("Daytime"), day.gamma[0], day.gamma[1], day.gamma[2]);
printf(_("Gamma (%s): %.3f, %.3f, %.3f\n"),
- "Night", night.gamma[0], night.gamma[1], night.gamma[2]);
+ _("Night"), night.gamma[0], night.gamma[1], night.gamma[2]);
}
/* Initialize gamma adjustment method. If method is NULL
@@ -1594,13 +1609,11 @@ main(int argc, char *argv[])
sizeof(color_setting_t));
/* Sleep for 5 seconds or 0.1 second. */
-#ifndef _WIN32
- if (short_trans_delta) usleep(SLEEP_DURATION_SHORT*1000);
- else usleep(SLEEP_DURATION*1000);
-#else /* ! _WIN32 */
- if (short_trans_delta) Sleep(SLEEP_DURATION_SHORT);
- else Sleep(SLEEP_DURATION);
-#endif /* ! _WIN32 */
+ if (short_trans_delta) {
+ systemtime_msleep(SLEEP_DURATION_SHORT);
+ } else {
+ systemtime_msleep(SLEEP_DURATION);
+ }
}
/* Restore saved gamma ramps */